@@ -3,7 +3,7 @@ BEGIN {
   $Git::CPAN::Patch::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Git::CPAN::Patch::VERSION = '1.1.2';
+  $Git::CPAN::Patch::VERSION = '1.2.0';
 }
 #ABSTRACT: Patch CPAN modules using Git
 
@@ -14,7 +14,7 @@ use MooseX::App 1.21;
 use MooseX::SemiAffordanceAccessor;
 
 use MetaCPAN::API;
-use Method::Signatures 20121201;
+use Method::Signatures::Simple 1.07;
 
 app_base 'git-cpan';
 app_namespace 'Git::CPAN::Patch::Command';
