@@ -3,7 +3,7 @@ BEGIN {
   $Git::CPAN::Patch::Command::Which::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Git::CPAN::Patch::Command::Which::VERSION = '1.1.2';
+  $Git::CPAN::Patch::Command::Which::VERSION = '1.2.0';
 }
 #ABSTRACT: reports the repository's module
 
@@ -12,7 +12,7 @@ use 5.10.0;
 use strict;
 use warnings;
 
-use Method::Signatures;
+use Method::Signatures::Simple;
 use MooseX::App::Command;
 
 with 'Git::CPAN::Patch::Role::Git'; 
