@@ -3,7 +3,7 @@ BEGIN {
   $Git::CPAN::Patch::Role::Patch::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Git::CPAN::Patch::Role::Patch::VERSION = '1.1.2';
+  $Git::CPAN::Patch::Role::Patch::VERSION = '1.2.0';
 }
 
 use 5.10.0;
@@ -11,7 +11,7 @@ use 5.10.0;
 use strict;
 use warnings;
 
-use Method::Signatures;
+use Method::Signatures::Simple;
 
 use Moose::Role;
 
